pub enum Error {
BitLengthTooLarge {
bit_length: u32,
bits_precision: u32,
},
BitLengthTooSmall {
bit_length: u32,
flavor: Flavor,
},
}Expand description
Errors returned by the crate’s API.
Variants
BitLengthTooLarge
The requested bit length of the candidate is larger than the maximum size of the target integer type.
Fields
BitLengthTooSmall
The requested bit length is too small to fit a prime of the chosen Flavor.